@@ -514,7 +514,7 @@ class UserFunctor(ABC, Datum):
     #root allows us to interpret '/' as something other than the top of the filesystem.
     def Copy(this, source, destination, root='/'):
         if (source.startswith('/')):
-            source = str(Path(root).joinpath(source).resolve())
+            source = str(Path(root).joinpath(source[1:]).resolve())
         else:
             source = str(Path(source).resolve())
         
@@ -540,6 +540,8 @@ class UserFunctor(ABC, Datum):
                 for error in errors:
                     src, dst, msg = error
                     logging.debug(f"{msg}")
+        else:
+            logging.error(f"Could not find source to copy: {source}")
 
     #Delete a file or folder
     def Delete(this, target):
@@ -565,7 +567,7 @@ class UserFunctor(ABC, Datum):
     #per https://stackoverflow.com/questions/803265/getting-realtime-output-using-subprocess
     def RunCommand(this, command, saveout=False, raiseExceptions=True):
         logging.debug(f"================ Running command: {command} ================")
-        p = Popen(command, stdout=PIPE, stderr=STDOUT, shell=True, bufsize=1)
+        p = Popen(command, stdout=PIPE, stderr=STDOUT, shell=True)
         output = []
         while p.poll() is None:
             line = p.stdout.readline().decode('utf8')[:-1]
@@ -758,13 +760,17 @@ class Executor(DataContainer, UserFunctor):
         logging.debug(f"...could not find {varName}; using default ({default})")
         return default
 
+
+    #UserFunctor method.
+    #We have to ParseArgs() here in order for other Executors to use ____KWArgs...
+    def ParseInitialArgs(this):
+        this.ParseArgs() #first, to enable debug and other such settings.
+        this.PopulateConfig()
+        this.PopulateRepoDetails()
         
     #UserFunctor required method
     #Override this with your own workflow.
     def UserFunction(this):
-        this.ParseArgs() #first, to enable debug and other such settings.
-        this.PopulateConfig()
-        this.PopulateRepoDetails()
         this.RegisterAllClasses()
         this.InitData()
 
